@@ -359,6 +359,12 @@ static fsal_status_t fsal_check_setattr_perms(struct fsal_obj_handle *obj,
 			 need_write_acl, need_write_data, need_write_attr);
 	}
 
+	if (access_check == 0) {
+		status = fsalstat(ERR_FSAL_NO_ERROR, 0);
+		note = " (No permission required)";
+		goto out;
+	}
+
 	if (current->acl) {
 		status = obj->obj_ops->test_access(obj, access_check, NULL,
 						   NULL, false);
@@ -1679,6 +1685,16 @@ fsal_status_t fsal_open2(struct fsal_obj_handle *in_obj, struct state_t *state,
 				       createmode >= FSAL_EXCLUSIVE, &reason);
 
 	if (FSAL_IS_ERROR(status)) {
+		if (status.major == ERR_FSAL_ACCESS &&
+		    createmode >= FSAL_EXCLUSIVE) {
+			/* Returning ACCESS err on exclusive open when the file
+			 * exists and we don't have permission to open it
+			 * doesn't make sense. This means that it is not an
+			 * exclusive replay and in this case we should return
+			 * EXIST and not ACCESS. */
+			status = fsalstat(ERR_FSAL_EXIST, 0);
+		}
+
 		LogDebug(COMPONENT_FSAL, "Not opening file %s%s", reason,
 			 fsal_err_txt(status));
 		return status;
@@ -2106,4 +2122,18 @@ out_error:
 	return status;
 }
 
+fsal_status_t fsal_close2(struct fsal_obj_handle *obj)
+{
+	fsal_status_t status = { ERR_FSAL_NO_ERROR, 0 };
+
+	if (close_fast) {
+		status = fsal_close(obj);
+
+		if (FSAL_IS_ERROR(status)) {
+			LogDebug(COMPONENT_FSAL, "%s failed with %s", __func__,
+				 fsal_err_txt(status));
+		}
+	}
+	return status;
+}
 /** @} */
