@@ -36,7 +36,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <pthread.h>
-#include <signal.h>		/* for sigaction */
+#include <signal.h> /* for sigaction */
 #include <errno.h>
 #include "fsal.h"
 #include "log.h"
@@ -46,42 +46,11 @@
 #include "conf_url.h"
 #include "sal_functions.h"
 
-/**
- * @brief LTTng trace enabling magic
- *
- * Every trace include file must be added here regardless whether it
- * is actually used in this source file.  The file must also be
- * included ONLY ONCE.  Failure to do so will create interesting
- * build time failure messages.  The key bit is the definitions of
- * TRACEPOINT_DEFINE and TRACEPOINT_PROBE_DYNAMIC_LINKAGE that are here
- * to trigger the global definitions as a shared object with the right
- * (weak) symbols to make the module loading optional.
- *
- * If and when this file gets some tracepoints of its own, the include
- * here is necessary and sufficient.
- */
-
-#ifdef USE_LTTNG
-#define TRACEPOINT_DEFINE
-#define TRACEPOINT_PROBE_DYNAMIC_LINKAGE
-
-#include "gsh_lttng/logger.h"
-#include "gsh_lttng/mdcache.h"
-#include "gsh_lttng/nfs_rpc.h"
-#include "gsh_lttng/nfs4.h"
-#include "gsh_lttng/state.h"
-#include "gsh_lttng/fsal_mem.h"
-#include "gsh_lttng/fsal_gluster.h"
-#include "gsh_lttng/fsal_ceph.h"
-#endif /* USE_LTTNG */
-
 /* parameters for NFSd startup and default values */
 
-nfs_start_info_t my_nfs_start_info = {
-	.dump_default_config = false,
-	.lw_mark_trigger = false,
-	.drop_caps = false
-};
+nfs_start_info_t my_nfs_start_info = { .dump_default_config = false,
+				       .lw_mark_trigger = false,
+				       .drop_caps = false };
 
 config_file_t nfs_config_struct;
 char *nfs_host_name = "localhost";
@@ -103,8 +72,7 @@ struct cleanup_list_element export_cleanup_element = {
  *
  */
 
-int nfs_libmain(const char *ganesha_conf,
-		const char *lpath,
+int nfs_libmain(const char *ganesha_conf, const char *lpath,
 		const int debug_level)
 {
 	char localmachine[MAXHOSTNAMELEN + 1];
@@ -117,7 +85,7 @@ int nfs_libmain(const char *ganesha_conf,
 
 	/* Set the server's boot time and epoch */
 	now(&nfs_ServerBootTime);
-	nfs_ServerEpoch = (time_t) nfs_ServerBootTime.tv_sec;
+	nfs_ServerEpoch = (time_t)nfs_ServerBootTime.tv_sec;
 
 	if (ganesha_conf)
 		nfs_config_path = gsh_strdup(ganesha_conf);
@@ -139,16 +107,15 @@ int nfs_libmain(const char *ganesha_conf,
 	}
 
 	/* initialize memory and logging */
-	nfs_prereq_init(exec_name, nfs_host_name, debug_level, log_path,
-			false, 8192 * 1024);
+	nfs_prereq_init(exec_name, nfs_host_name, debug_level, log_path, false,
+			8192 * 1024);
 #if GANESHA_BUILD_RELEASE
-	LogEvent(COMPONENT_MAIN, "%s Starting: Ganesha Version %s",
-		 exec_name, GANESHA_VERSION);
+	LogEvent(COMPONENT_MAIN, "%s Starting: Ganesha Version %s", exec_name,
+		 GANESHA_VERSION);
 #else
-	LogEvent(COMPONENT_MAIN, "%s Starting: %s",
-		 exec_name,
-		 "Ganesha Version " _GIT_DESCRIBE ", built at "
-		 __DATE__ " " __TIME__ " on " BUILD_HOST);
+	LogEvent(COMPONENT_MAIN, "%s Starting: %s", exec_name,
+		 "Ganesha Version " _GIT_DESCRIBE ", built at " __DATE__
+		 " " __TIME__ " on " BUILD_HOST);
 #endif
 
 	/* initialize nfs_init */
@@ -168,8 +135,7 @@ int nfs_libmain(const char *ganesha_conf,
 	sigemptyset(&signals_to_block);
 	sigaddset(&signals_to_block, SIGPIPE); /* XXX */
 	if (pthread_sigmask(SIG_BLOCK, &signals_to_block, NULL) != 0)
-		LogFatal(COMPONENT_MAIN,
-			 "pthread_sigmask failed");
+		LogFatal(COMPONENT_MAIN, "pthread_sigmask failed");
 
 	/* init URL package */
 	config_url_init();
@@ -179,8 +145,7 @@ int nfs_libmain(const char *ganesha_conf,
 		goto fatal_die;
 
 	if (nfs_config_path == NULL || nfs_config_path[0] == '\0') {
-		LogWarn(COMPONENT_INIT,
-			"No configuration file named.");
+		LogWarn(COMPONENT_INIT, "No configuration file named.");
 		nfs_config_struct = NULL;
 	} else
 		nfs_config_struct =
@@ -190,16 +155,14 @@ int nfs_libmain(const char *ganesha_conf,
 		char *errstr = err_type_str(&err_type);
 
 		if (!config_error_is_harmless(&err_type)) {
-			LogCrit(COMPONENT_INIT,
-				 "Error %s while parsing (%s)",
-				 errstr != NULL ? errstr : "unknown",
-				 nfs_config_path);
+			LogCrit(COMPONENT_INIT, "Error %s while parsing (%s)",
+				errstr != NULL ? errstr : "unknown",
+				nfs_config_path);
 			if (errstr != NULL)
 				gsh_free(errstr);
 			goto fatal_die;
 		} else
-			LogWarn(COMPONENT_INIT,
-				"Error %s while parsing (%s)",
+			LogWarn(COMPONENT_INIT, "Error %s while parsing (%s)",
 				errstr != NULL ? errstr : "unknown",
 				nfs_config_path);
 		if (errstr != NULL)
@@ -208,7 +171,7 @@ int nfs_libmain(const char *ganesha_conf,
 
 	if (read_log_config(nfs_config_struct, &err_type) < 0) {
 		LogCrit(COMPONENT_INIT,
-			 "Error while parsing log configuration");
+			"Error while parsing log configuration");
 		goto fatal_die;
 	}
 
@@ -216,25 +179,22 @@ int nfs_libmain(const char *ganesha_conf,
 	 * the list available at exports parsing time.
 	 */
 	if (start_fsals(nfs_config_struct, &err_type) < 0) {
-		LogCrit(COMPONENT_INIT,
-			 "Error starting FSALs.");
+		LogCrit(COMPONENT_INIT, "Error starting FSALs.");
 		goto fatal_die;
 	}
 
 	/* parse configuration file */
 
-	if (nfs_set_param_from_conf(nfs_config_struct,
-				    &my_nfs_start_info,
+	if (nfs_set_param_from_conf(nfs_config_struct, &my_nfs_start_info,
 				    &err_type)) {
 		LogCrit(COMPONENT_INIT,
-			 "Error setting parameters from configuration file.");
+			"Error setting parameters from configuration file.");
 		goto fatal_die;
 	}
 
 	/* initialize core subsystems and data structures */
 	if (init_server_pkgs() != 0) {
-		LogCrit(COMPONENT_INIT,
-			"Failed to initialize server packages");
+		LogCrit(COMPONENT_INIT, "Failed to initialize server packages");
 		goto fatal_die;
 	}
 
@@ -243,19 +203,17 @@ int nfs_libmain(const char *ganesha_conf,
 	 */
 	dsc = ReadDataServers(nfs_config_struct, &err_type);
 	if (dsc < 0) {
-		LogCrit(COMPONENT_INIT,
-			"Error while parsing DS entries");
+		LogCrit(COMPONENT_INIT, "Error while parsing DS entries");
 		goto fatal_die;
 	}
 
-
 	/* Create stable storage directory, this needs to be done before
 	 * starting the recovery thread.
 	 */
 	rc = nfs4_recovery_init();
 	if (rc) {
 		LogCrit(COMPONENT_INIT,
-			  "Recovery backend initialization failed!");
+			"Recovery backend initialization failed!");
 		goto fatal_die;
 	}
 
@@ -273,14 +231,13 @@ int nfs_libmain(const char *ganesha_conf,
 	 */
 	rc = ReadExports(nfs_config_struct, &err_type);
 	if (rc < 0) {
-		LogCrit(COMPONENT_INIT,
-			  "Error while parsing export entries");
+		LogCrit(COMPONENT_INIT, "Error while parsing export entries");
 		goto fatal_die;
 	}
 	if (rc == 0 && dsc == 0)
 		LogWarn(COMPONENT_INIT,
 			"No export entries found in configuration file !!!");
-	(void) report_config_errors(&err_type, NULL, config_errs_to_log);
+	(void)report_config_errors(&err_type, NULL, config_errs_to_log);
 
 	/* freeing syntax tree : */
 
@@ -294,9 +251,8 @@ int nfs_libmain(const char *ganesha_conf,
 	return 0;
 
 fatal_die:
-	(void) report_config_errors(&err_type, NULL, config_errs_to_log);
-	LogFatal(COMPONENT_INIT,
-		 "Fatal errors.  Server exiting...");
+	(void)report_config_errors(&err_type, NULL, config_errs_to_log);
+	LogFatal(COMPONENT_INIT, "Fatal errors.  Server exiting...");
 	/* NOT REACHED */
 	return 2;
 }
