@@ -807,7 +807,7 @@ enum nfs_req_result process_one_op(compound_data_t *data, nfsstat4 *status)
 			   " %s is %s",
 			   data->oppos, data->argarray_len - 1,
 			   session_compare ? "same session as SEQUENCE" :
-					     "different session from SEQUENCE",
+						   "different session from SEQUENCE",
 			   bad_pos ? "not last op in compound" : "opk");
 
 		if (bad_pos) {
@@ -1045,11 +1045,7 @@ void complete_nfs4_compound(compound_data_t *data, int status,
 	/* If we have reserved a lease, update it and release it */
 	if (data->preserved_clientid != NULL) {
 		/* Update and release lease */
-		PTHREAD_MUTEX_lock(&data->preserved_clientid->cid_mutex);
-
-		update_lease(data->preserved_clientid);
-
-		PTHREAD_MUTEX_unlock(&data->preserved_clientid->cid_mutex);
+		update_lease_simple(data->preserved_clientid);
 	}
 
 	if (status != NFS4_OK)
@@ -1269,6 +1265,10 @@ int nfs4_Compound(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 	LogDebug(COMPONENT_NFS_V4,
 		 "COMPOUND: There are %d operations, res = %p, tag = %s",
 		 argarray_len, res, data->tagname);
+	GSH_AUTO_TRACEPOINT(
+		nfs_rpc, compound_start, TRACE_INFO,
+		"COMPOUND: There are {} operations, minor = {}, tag = {}",
+		argarray_len, compound4_minor, TP_STR(data->tagname));
 
 	/* Check for empty COMPOUND request */
 	if (argarray_len == 0) {
@@ -1424,8 +1424,8 @@ void nfs4_Compound_FreeOne(nfs_resop4 *res)
 	int opcode;
 
 	opcode = (res->resop != NFS4_OP_ILLEGAL) ?
-			 res->resop :
-			 0; /* opcode 0 for illegals */
+			       res->resop :
+			       0; /* opcode 0 for illegals */
 	optabv4[opcode].free_res(res);
 }
 
