@@ -46,6 +46,11 @@
 #include "export_mgr.h"
 #include "nfs_rpc_callback.h"
 
+#include "gsh_lttng/gsh_lttng.h"
+#if defined(USE_LTTNG) && !defined(LTTNG_PARSING)
+#include "gsh_lttng/generated_traces/nfs4.h"
+#endif
+
 static const char *open_tag = "OPEN";
 
 /**
@@ -175,7 +180,7 @@ static nfsstat4 open4_validate_claim(compound_data_t *data,
 				*grace_ref = true;
 			} else {
 				status = want_grace ? NFS4ERR_NO_GRACE :
-						      NFS4ERR_GRACE;
+							    NFS4ERR_GRACE;
 			}
 		} else {
 			*grace_ref = false;
@@ -1265,6 +1270,13 @@ enum nfs_req_result nfs4_op_open(struct nfs_argop4 *op, compound_data_t *data,
 		arg_OPEN4->claim.claim, arg_OPEN4->openhow.opentype,
 		arg_OPEN4->share_deny, arg_OPEN4->share_access);
 
+	GSH_AUTO_TRACEPOINT(
+		nfs4, op_open_start, TRACE_INFO,
+		"OPEN arg: claim={} opentype={} howmode={} share_deny={} share_access={} seqid={}",
+		arg_OPEN4->claim.claim, arg_OPEN4->openhow.opentype,
+		arg_OPEN4->openhow.openflag4_u.how.mode, arg_OPEN4->share_deny,
+		arg_OPEN4->share_access, arg_OPEN4->seqid);
+
 	resp->resop = NFS4_OP_OPEN;
 	res_OPEN4->status = NFS4_OK;
 	res_OPEN4->OPEN4res_u.resok4.rflags = 0;
@@ -1320,8 +1332,8 @@ enum nfs_req_result nfs4_op_open(struct nfs_argop4 *op, compound_data_t *data,
 		 arg_OPEN4->owner.clientid);
 
 	retval = nfs_client_id_get_confirmed(data->minorversion == 0 ?
-						     arg_OPEN4->owner.clientid :
-						     data->session->clientid,
+							   arg_OPEN4->owner.clientid :
+							   data->session->clientid,
 					     &clientid);
 
 	if (retval != CLIENT_ID_SUCCESS) {
@@ -1445,7 +1457,7 @@ enum nfs_req_result nfs4_op_open(struct nfs_argop4 *op, compound_data_t *data,
 
 	res_OPEN4->OPEN4res_u.resok4.cinfo.atomic =
 		is_parent_pre_attrs_valid && is_parent_post_attrs_valid ? TRUE :
-									  FALSE;
+										FALSE;
 
 	/* Handle open stateid/seqid for success */
 	update_stateid(file_state, &res_OPEN4->OPEN4res_u.resok4.stateid, data,
@@ -1475,11 +1487,8 @@ out2:
 		nfs_put_grace_status();
 
 	/* Update the lease before exit */
-	if (data->minorversion == 0) {
-		PTHREAD_MUTEX_lock(&clientid->cid_mutex);
-		update_lease(clientid);
-		PTHREAD_MUTEX_unlock(&clientid->cid_mutex);
-	}
+	if (data->minorversion == 0)
+		update_lease_simple(clientid);
 
 	if (file_state != NULL)
 		dec_state_t_ref(file_state);
@@ -1503,6 +1512,15 @@ out3:
 
 	dec_client_id_ref(clientid);
 
+	const OPEN4resok *const resok = &res_OPEN4->OPEN4res_u.resok4;
+
+	GSH_AUTO_TRACEPOINT(nfs4, op_open_end, TRACE_INFO,
+			    "OPEN res: status={} stateid={} " TP_CINFO_FORMAT
+			    " rflags={} delegation={}",
+			    res_OPEN4->status, resok->stateid.seqid,
+			    TP_CINFO_ARGS_EXPAND(resok->cinfo), resok->rflags,
+			    resok->delegation.delegation_type);
+
 	return nfsstat4_to_nfs_req_result(res_OPEN4->status);
 } /* nfs4_op_open */
 
