@@ -40,8 +40,11 @@
 #include "nfs_core.h"
 #include "nfs_proto_functions.h"
 #include "sal_functions.h"
-#ifdef USE_LTTNG
-#include "gsh_lttng/nfs4.h"
+#include "xprt_handler.h"
+
+#include "gsh_lttng/gsh_lttng.h"
+#if defined(USE_LTTNG) && !defined(LTTNG_PARSING)
+#include "gsh_lttng/generated_traces/nfs4.h"
 #endif
 
 /**
@@ -75,8 +78,7 @@ int display_session_id(struct display_buffer *dspbuf, char *session_id)
 	int b_left = display_cat(dspbuf, "sessionid=");
 
 	if (b_left > 0)
-		b_left = display_opaque_value(dspbuf,
-					      session_id,
+		b_left = display_opaque_value(dspbuf, session_id,
 					      NFS4_SESSIONID_SIZE);
 
 	return b_left;
@@ -90,7 +92,7 @@ int display_session_id(struct display_buffer *dspbuf, char *session_id)
  */
 
 int display_session_id_key(struct display_buffer *dspbuf,
-			      struct gsh_buffdesc *buff)
+			   struct gsh_buffdesc *buff)
 {
 	return display_session_id(dspbuf, buff->addr);
 }
@@ -128,7 +130,7 @@ int display_session(struct display_buffer *dspbuf, nfs41_session_t *session)
  */
 
 int display_nfs4_operations(struct display_buffer *dspbuf, nfs_opnum4 *opcodes,
-	uint32_t opcode_num)
+			    uint32_t opcode_num)
 {
 	uint32_t i = 0;
 
@@ -136,7 +138,7 @@ int display_nfs4_operations(struct display_buffer *dspbuf, nfs_opnum4 *opcodes,
 
 	while (b_left > 0 && i < opcode_num) {
 		if (i > 0)
-			(void) display_cat(dspbuf, ", ");
+			(void)display_cat(dspbuf, ", ");
 
 		b_left = display_cat(dspbuf, nfsop4_to_str(opcodes[i]));
 		i++;
@@ -156,7 +158,7 @@ int display_nfs4_operations(struct display_buffer *dspbuf, nfs_opnum4 *opcodes,
  */
 
 int display_session_id_val(struct display_buffer *dspbuf,
-			      struct gsh_buffdesc *buff)
+			   struct gsh_buffdesc *buff)
 {
 	return display_session(dspbuf, buff->addr);
 }
@@ -263,9 +265,9 @@ void nfs41_Build_sessionid(clientid4 *clientid, char *sessionid)
 int32_t _inc_session_ref(nfs41_session_t *session, const char *func, int line)
 {
 	int32_t refcnt = atomic_inc_int32_t(&session->refcount);
-#ifdef USE_LTTNG
-	tracepoint(nfs4, session_ref, func, line, session, refcnt);
-#endif
+	GSH_AUTO_TRACEPOINT(nfs4, incref, TRACE_INFO,
+			    "Session incref. Session: {}, refcount: {}",
+			    session, refcnt);
 	return refcnt;
 }
 
@@ -273,14 +275,13 @@ int32_t _dec_session_ref(nfs41_session_t *session, const char *func, int line)
 {
 	int i;
 	int32_t refcnt = atomic_dec_int32_t(&session->refcount);
-#ifdef USE_LTTNG
-	tracepoint(nfs4, session_unref, func, line, session, refcnt);
-#endif
+	GSH_AUTO_TRACEPOINT(nfs4, decref, TRACE_INFO,
+			    "Session decref. Session: {}, refcount: {}",
+			    session, refcnt);
 
 	assert(refcnt >= 0);
 
 	if (refcnt == 0) {
-
 		/* Unlink the session from the client's list of
 		   sessions */
 		PTHREAD_MUTEX_lock(&session->clientid_record->cid_mutex);
@@ -309,6 +310,26 @@ int32_t _dec_session_ref(nfs41_session_t *session, const char *func, int line)
 
 		PTHREAD_MUTEX_destroy(&session->cb_chan.chan_mtx);
 
+		/* Free the session's callback security params */
+		for (i = 0; i < session->cb_sec_parms.sec_parms_len; ++i) {
+			callback_sec_parms4 *const sp =
+				&session->cb_sec_parms.sec_parms_val[i];
+			if (sp->cb_secflavor == AUTH_NONE) {
+				/* Do nothing */
+			} else if (sp->cb_secflavor == AUTH_SYS) {
+				struct authunix_parms *cb_auth_sys_params =
+					&sp->callback_sec_parms4_u.cbsp_sys_cred;
+				gsh_free(cb_auth_sys_params->aup_machname);
+				gsh_free(cb_auth_sys_params->aup_gids);
+#ifdef _HAVE_GSSAPI
+			} else if (sp->cb_secflavor == RPCSEC_GSS) {
+				LogWarn(COMPONENT_SESSIONS,
+					"GSS callbacks unsupported, skip");
+#endif
+			}
+		}
+		gsh_free(session->cb_sec_parms.sec_parms_val);
+
 		/* Free the slot tables */
 		gsh_free(session->fc_slots);
 		gsh_free(session->bc_slots);
@@ -354,14 +375,13 @@ int nfs41_Session_Set(nfs41_session_t *session_data)
 	if (code == HASHTABLE_ERROR_NO_SUCH_KEY) {
 		/* nfs4_op_create_session ensures refcount == 2 for new
 		 * session records */
-		code =
-		    hashtable_setlatched(ht_session_id, &key, &val, &latch,
-					 false, NULL, NULL);
+		code = hashtable_setlatched(ht_session_id, &key, &val, &latch,
+					    false, NULL, NULL);
 		if (code == HASHTABLE_SUCCESS)
 			rc = 1;
 	}
 
- out:
+out:
 	return rc;
 }
 
@@ -382,7 +402,7 @@ int nfs41_Session_Get_Pointer(char sessionid[NFS4_SESSIONID_SIZE],
 	struct gsh_buffdesc val;
 	struct hash_latch latch;
 	char str[LOG_BUFF_LEN] = "\0";
-	struct display_buffer dspbuf = {sizeof(str), str, str};
+	struct display_buffer dspbuf = { sizeof(str), str, str };
 	bool str_valid = false;
 	hash_error_t code;
 
@@ -399,13 +419,13 @@ int nfs41_Session_Get_Pointer(char sessionid[NFS4_SESSIONID_SIZE],
 	if (code != HASHTABLE_SUCCESS) {
 		hashtable_releaselatched(ht_session_id, &latch);
 		if (str_valid)
-			LogFullDebug(COMPONENT_SESSIONS,
-				     "Session %s Not Found", str);
+			LogFullDebug(COMPONENT_SESSIONS, "Session %s Not Found",
+				     str);
 		return 0;
 	}
 
 	*session_data = val.addr;
-	inc_session_ref(*session_data);	/* XXX more locks? */
+	inc_session_ref(*session_data); /* XXX more locks? */
 
 	hashtable_releaselatched(ht_session_id, &latch);
 
@@ -415,6 +435,36 @@ int nfs41_Session_Get_Pointer(char sessionid[NFS4_SESSIONID_SIZE],
 	return 1;
 }
 
+/**
+ * @brief Release all connections (SVCXPRT) referenced by the session
+ */
+static void release_all_session_connections(nfs41_session_t *session)
+{
+	struct glist_head *curr_node, *next_node;
+
+	/* Take connections write-lock */
+	PTHREAD_RWLOCK_wrlock(&session->conn_lock);
+
+	glist_for_each_safe(curr_node, next_node, &session->connection_xprts)
+	{
+		connection_xprt_t *const curr_entry =
+			glist_entry(curr_node, connection_xprt_t, node);
+		SVCXPRT *const xprt = curr_entry->xprt;
+
+		remove_nfs41_session_from_xprt(xprt, session);
+
+		/* Release the connection-xprt's ref held by the session being
+		 * destroyed.
+		 */
+		SVC_RELEASE(xprt, SVC_RELEASE_FLAG_NONE);
+
+		glist_del(curr_node);
+		gsh_free(curr_entry);
+	}
+	session->num_conn = 0;
+	PTHREAD_RWLOCK_unlock(&session->conn_lock);
+}
+
 /**
  * @brief Remove a session from the session hashtable.
  *
@@ -426,11 +476,14 @@ int nfs41_Session_Get_Pointer(char sessionid[NFS4_SESSIONID_SIZE],
  * @retval 0 otherwise.
  */
 
-int nfs41_Session_Del(char sessionid[NFS4_SESSIONID_SIZE])
+int nfs41_Session_Del(nfs41_session_t *session)
 {
 	struct gsh_buffdesc key, old_key, old_value;
 
-	key.addr = sessionid;
+	/* Release all session connections */
+	release_all_session_connections(session);
+
+	key.addr = session->session_id;
 	key.len = NFS4_SESSIONID_SIZE;
 
 	if (HashTable_Del(ht_session_id, &key, &old_key, &old_value) ==
@@ -455,61 +508,59 @@ void nfs41_Session_PrintAll(void)
 	hashtable_log(COMPONENT_SESSIONS, ht_session_id);
 }
 
-bool check_session_conn(nfs41_session_t *session,
-			compound_data_t *data,
+bool check_session_conn(nfs41_session_t *session, compound_data_t *data,
 			bool can_associate)
 {
-	int i, num;
-	sockaddr_t addr;
+	struct glist_head *curr_node;
+	bool added_session_to_xprt;
 	bool associate = false;
 
-	/* Copy the address coming over the wire. */
-	copy_xprt_addr(&addr, data->req->rq_xprt);
-
 	PTHREAD_RWLOCK_rdlock(&session->conn_lock);
 
 retry:
 
-	/* Save number of connections for use outside the lock */
-	num = session->num_conn;
+	glist_for_each(curr_node, &session->connection_xprts)
+	{
+		connection_xprt_t *const curr_entry =
+			glist_entry(curr_node, connection_xprt_t, node);
 
-	for (i = 0; i < session->num_conn; i++) {
 		if (isFullDebug(COMPONENT_SESSIONS)) {
-			char str1[LOG_BUFF_LEN / 2] = "\0";
-			char str2[LOG_BUFF_LEN / 2] = "\0";
-			struct display_buffer db1 = {sizeof(str1), str1, str1};
-			struct display_buffer db2 = {sizeof(str2), str2, str2};
+			char str1[SOCK_NAME_MAX] = "\0";
+			char str2[SOCK_NAME_MAX] = "\0";
+			struct display_buffer db1 = { sizeof(str1), str1,
+						      str1 };
+			struct display_buffer db2 = { sizeof(str2), str2,
+						      str2 };
 
-			display_sockaddr(&db1, &addr);
-			display_sockaddr(&db2, &session->connections[i]);
-			LogFullDebug(COMPONENT_SESSIONS,
-				     "Comparing addr %s for %s to Session bound addr %s",
-				     str1, data->opname, str2);
+			display_xprt_sockaddr(&db1, data->req->rq_xprt);
+			display_xprt_sockaddr(&db2, curr_entry->xprt);
+			LogFullDebug(
+				COMPONENT_SESSIONS,
+				"Comparing addr %s for %s to Session bound addr %s",
+				str1, data->opname, str2);
 		}
 
-		if (cmp_sockaddr(&addr, &session->connections[i], false)) {
+		if (data->req->rq_xprt == curr_entry->xprt) {
 			/* We found a match */
 			PTHREAD_RWLOCK_unlock(&session->conn_lock);
 			return true;
 		}
 	}
 
-	if (!can_associate || num == NFS41_MAX_CONNECTIONS) {
-		/* We either aren't allowed to associate a new address or there
-		 * is no room.
-		 */
+	if (!can_associate) {
+		/* We either aren't allowed to associate a new address */
 		PTHREAD_RWLOCK_unlock(&session->conn_lock);
 
 		if (isDebug(COMPONENT_SESSIONS)) {
-			char str1[LOG_BUFF_LEN / 2] = "\0";
-			struct display_buffer db1 = {sizeof(str1), str1, str1};
+			char str1[SOCK_NAME_MAX] = "\0";
+			struct display_buffer db1 = { sizeof(str1), str1,
+						      str1 };
 
-			display_sockaddr(&db1, &addr);
+			display_xprt_sockaddr(&db1, data->req->rq_xprt);
 			LogDebug(COMPONENT_SESSIONS,
-				     "Found no match for addr %s for %s",
-				     str1, data->opname);
+				 "Found no match for addr %s for %s", str1,
+				 data->opname);
 		}
-
 		return false;
 	}
 
@@ -523,12 +574,160 @@ retry:
 		goto retry;
 	}
 
-	/* Add the new connection. */
-	memcpy(&session->connections[session->num_conn++], &addr, sizeof(addr));
+	if (session->num_conn == NFS41_MAX_CONNECTIONS) {
+		LogInfo(COMPONENT_SESSIONS,
+			"We hit the session's max-connections limit before adding xprt FD: %d",
+			data->req->rq_xprt->xp_fd);
+	}
+
+	/* Add session to the xprt */
+	added_session_to_xprt =
+		add_nfs41_session_to_xprt(data->req->rq_xprt, session);
+
+	if (!added_session_to_xprt) {
+		PTHREAD_RWLOCK_unlock(&session->conn_lock);
+		LogWarn(COMPONENT_SESSIONS,
+			"Could not associate xprt FD: %d with session",
+			data->req->rq_xprt->xp_fd);
+		return false;
+	}
+
+	/* Add xprt to the session */
+	nfs41_Session_Add_Connection(session, data->req->rq_xprt);
 
 	PTHREAD_RWLOCK_unlock(&session->conn_lock);
-
 	return true;
 }
 
+/**
+ * @brief Adds the xprt reference to the nfs41_session
+ *
+ * @note The caller must hold the `session->conn_lock` lock for writes.
+ */
+void nfs41_Session_Add_Connection(nfs41_session_t *session, SVCXPRT *xprt)
+{
+	connection_xprt_t *const new_entry =
+		gsh_malloc(sizeof(connection_xprt_t));
+	new_entry->xprt = xprt;
+	glist_add_tail(&session->connection_xprts, &new_entry->node);
+	SVC_REF(xprt, SVC_REF_FLAG_NONE);
+	session->num_conn++;
+}
+
+/**
+ * @brief Remove matching connection (SVCXPRT) from the session
+ */
+void nfs41_Session_Remove_Connection(nfs41_session_t *session, SVCXPRT *xprt)
+{
+	struct glist_head *curr_node;
+	connection_xprt_t *found_xprt = NULL;
+	char xprt_addr[SOCK_NAME_MAX] = "\0";
+	struct display_buffer xprt_db = { sizeof(xprt_addr), xprt_addr,
+					  xprt_addr };
+
+	display_xprt_sockaddr(&xprt_db, xprt);
+	PTHREAD_RWLOCK_wrlock(&session->conn_lock);
+
+	glist_for_each(curr_node, &session->connection_xprts)
+	{
+		connection_xprt_t *const curr_entry =
+			glist_entry(curr_node, connection_xprt_t, node);
+
+		if (isFullDebug(COMPONENT_SESSIONS)) {
+			char curr_xprt_addr[SOCK_NAME_MAX] = "\0";
+			struct display_buffer db = { sizeof(curr_xprt_addr),
+						     curr_xprt_addr,
+						     curr_xprt_addr };
+
+			display_xprt_sockaddr(&db, curr_entry->xprt);
+			LogFullDebug(
+				COMPONENT_SESSIONS,
+				"Comparing input xprt addr %s to session bound xprt addr %s",
+				xprt_addr, curr_xprt_addr);
+		}
+
+		/* During removal, the xprt address must match, and not just the
+		 * socket-address. We do not want to remove a different xprt
+		 * with same socket-address.
+		 */
+		if (curr_entry->xprt == xprt) {
+			found_xprt = curr_entry;
+			break;
+		}
+	}
+
+	/* Return if the connection is not bound to the session.
+	 * This can happen in rare situations when the session is destroyed
+	 * and all its connections were removed, just before we obtained
+	 * the above conn_lock.
+	 */
+	if (found_xprt == NULL) {
+		PTHREAD_RWLOCK_unlock(&session->conn_lock);
+		assert(session->num_conn == 0);
+		return;
+	}
+
+	/* Now, remove the matching connection from session */
+
+	/* Release the connection-xprt's ref held on the session */
+	SVC_RELEASE(found_xprt->xprt, SVC_RELEASE_FLAG_NONE);
+
+	/* Remove the xprt from session's connection-xprts */
+	glist_del(&found_xprt->node);
+	gsh_free(found_xprt);
+	session->num_conn--;
+
+	PTHREAD_RWLOCK_unlock(&session->conn_lock);
+	LogDebug(COMPONENT_SESSIONS,
+		 "Successfuly removed the connection for xprt addr %s",
+		 xprt_addr);
+}
+
+/**
+ * This function destroys the input session's backchannel if it is up, and if
+ * it uses the input xprt.
+ */
+void nfs41_Session_Destroy_Backchannel_For_Xprt(nfs41_session_t *session,
+						SVCXPRT *xprt)
+{
+	char session_str[NFS4_SESSIONID_BUFFER_SIZE] = "\0";
+	struct display_buffer db2 = { sizeof(session_str), session_str,
+				      session_str };
+
+	display_session_id(&db2, session->session_id);
+	PTHREAD_MUTEX_lock(&session->cb_chan.chan_mtx);
+
+	/* After acquiring the lock, we check backchannel availability */
+	if (session->cb_chan.clnt == NULL) {
+		PTHREAD_MUTEX_unlock(&session->cb_chan.chan_mtx);
+		goto no_backchannel;
+	}
+	/* Given that the backchannel is up, we first check if the session's
+	 * backchannel actually uses the xprt being destroyed.
+	 * The channel lock ensures that channel's client check (below) and the
+	 * channel destroy operation are performed atomically.
+	 */
+	if (clnt_vc_get_client_xprt(session->cb_chan.clnt) != xprt) {
+		PTHREAD_MUTEX_unlock(&session->cb_chan.chan_mtx);
+		LogDebug(
+			COMPONENT_SESSIONS,
+			"Backchannel xprt for session %s does not match the xprt to be destroyed. Skip destroying backchannel",
+			session_str);
+		return;
+	}
+	/* Now destroy the backchannel */
+	nfs_rpc_destroy_chan_no_lock(&session->cb_chan);
+	atomic_clear_uint32_t_bits(&session->flags, session_bc_up);
+	PTHREAD_MUTEX_unlock(&session->cb_chan.chan_mtx);
+
+	LogDebug(COMPONENT_SESSIONS,
+		 "Backchannel destroyed for current session %s", session_str);
+	return;
+
+no_backchannel:
+	LogDebug(COMPONENT_SESSIONS,
+		 "Backchannel is not up for session %s, skip destroying it",
+		 session_str);
+}
+
 /** @} */
