@@ -52,6 +52,11 @@
 #include "city.h"
 #include "client_mgr.h"
 
+#include "gsh_lttng/gsh_lttng.h"
+#if defined(USE_LTTNG) && !defined(LTTNG_PARSING)
+#include "gsh_lttng/generated_traces/nfs4.h"
+#endif
+
 /**
  * @brief Hashtable used to cache NFSv4 clientids
  */
@@ -89,6 +94,12 @@ uint32_t num_of_curr_expired_clients;
  * @brief Global list to store expired client IDs and it's mutex
  */
 struct glist_head expired_client_ids_list;
+
+/**
+ * @brief Mutex to protect the above list. This mutex MUST NOT be taken while
+ *        holding the cid_mutex. Taking the cid_mutex while holding this mutex
+ *        is OK and expected.
+ */
 pthread_mutex_t expired_client_ids_list_lock;
 
 /**
@@ -272,6 +283,10 @@ int32_t inc_client_id_ref(nfs_client_id_t *clientid)
 {
 	int32_t cid_refcount = atomic_inc_int32_t(&clientid->cid_refcount);
 
+	GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, incref_client_id, TRACE_INFO,
+				      clientid, "Incref client id. refcount={}",
+				      cid_refcount);
+
 	if (isFullDebug(COMPONENT_CLIENTID)) {
 		char str[LOG_BUFF_LEN] = "\0";
 		struct display_buffer dspbuf = { sizeof(str), str, str };
@@ -324,6 +339,9 @@ bool client_id_has_state(nfs_client_id_t *clientid)
 
 void free_client_id(nfs_client_id_t *clientid)
 {
+	GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, free_client_id, TRACE_INFO,
+				      clientid, "Free client id");
+
 	assert(atomic_fetch_int32_t(&clientid->cid_refcount) == 0);
 
 	/* This is where we finally let go of the client record. */
@@ -347,7 +365,15 @@ void free_client_id(nfs_client_id_t *clientid)
 		{
 			nfs41_session_t *session = glist_entry(
 				glist, nfs41_session_t, session_link);
-			nfs41_Session_Del(session);
+			if (!nfs41_Session_Del(session)) {
+				char str[LOG_BUFF_LEN] = "\0";
+				struct display_buffer dspbuf = { sizeof(str),
+								 str, str };
+
+				display_client_id_rec(&dspbuf, clientid);
+				LogCrit(COMPONENT_SESSIONS,
+					"Expire session failed for {%s}", str);
+			}
 		}
 	}
 
@@ -380,6 +406,9 @@ int32_t dec_client_id_ref(nfs_client_id_t *clientid)
 
 	cid_refcount = atomic_dec_int32_t(&clientid->cid_refcount);
 
+	GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, client_decref, TRACE_INFO, clientid,
+				      "Decref, refcount={}", cid_refcount);
+
 	LogFullDebug(COMPONENT_CLIENTID,
 		     "Decrement refcount Clientid {%s} cid_refcount to %d", str,
 		     cid_refcount);
@@ -689,9 +718,17 @@ int remove_confirmed_client_id(nfs_client_id_t *clientid)
 			 "Could not remove unconfirmed clientid %" PRIx64
 			 " error=%s",
 			 clientid->cid_clientid, hash_table_err_to_str(rc));
+		GSH_CLIENT_ID_AUTO_TRACEPOINT(
+			nfs4, remove_confirmed_client_id_failed, TRACE_ERR,
+			clientid,
+			"Could not remove unconfirmed clientid. error={}", rc);
 		return rc;
 	}
 
+	GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, remove_confirmed_client_id,
+				      TRACE_INFO, clientid,
+				      "Remove confirmed client id");
+
 	clientid->cid_client_record->cr_confirmed_rec = NULL;
 
 	/* Set this up so this client id record will be freed. */
@@ -730,9 +767,18 @@ int remove_unconfirmed_client_id(nfs_client_id_t *clientid)
 			"Could not remove unconfirmed clientid %" PRIx64
 			" error=%s",
 			clientid->cid_clientid, hash_table_err_to_str(rc));
+		GSH_CLIENT_ID_AUTO_TRACEPOINT(
+			nfs4, remove_unconfirmed_client_id_failed, TRACE_ERR,
+			clientid,
+			"Could not remove ununconfirmed clientid. error={}",
+			rc);
 		return rc;
 	}
 
+	GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, remove_unconfirmed_client_id,
+				      TRACE_INFO, clientid,
+				      "Remove unconfirmed client id");
+
 	/* XXX prevents calling remove_confirmed before removed_confirmed,
 	 * if we failed to maintain the invariant that the cases are
 	 * disjoint */
@@ -832,6 +878,9 @@ clientid_status_t nfs_client_id_confirm(nfs_client_id_t *clientid,
 
 	nfs4_add_clid(clientid);
 
+	GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, confirm_client_id, TRACE_INFO,
+				      clientid, "Client id confirmed");
+
 	return CLIENT_ID_SUCCESS;
 }
 
@@ -934,6 +983,8 @@ void print_expired_client_list(void)
 /**
  * @brief Remove client from expired client list.
  *
+ * NOTE: Must not be called with cid_mutex held (lock ordering).
+ *
  * @param[in] active_clientid The client id of interest
  *
  * @retval NA
@@ -946,6 +997,7 @@ void remove_client_from_expired_client_list(nfs_client_id_t *active_clientid)
 	struct glist_head *expired_client_n = NULL;
 
 	PTHREAD_MUTEX_lock(&expired_client_ids_list_lock);
+
 	glist_for_each_safe(expired_client_i, expired_client_n,
 			    &expired_client_ids_list)
 	{
@@ -959,12 +1011,18 @@ void remove_client_from_expired_client_list(nfs_client_id_t *active_clientid)
 		}
 
 		/* Found the client to be removed */
+		PTHREAD_MUTEX_lock(&expired_client->cid_mutex);
+
 		glist_del(&expired_client->expired_client);
 		expired_client->marked_for_delayed_cleanup = false;
+		atomic_dec_uint32_t(&num_of_curr_expired_clients);
+
+		PTHREAD_MUTEX_unlock(&expired_client->cid_mutex);
+
 		/* Drop ref of the expired_client as it's gone valid */
 		dec_client_id_ref(expired_client);
-		atomic_dec_uint32_t(&num_of_curr_expired_clients);
 	}
+
 	PTHREAD_MUTEX_unlock(&expired_client_ids_list_lock);
 }
 
@@ -993,6 +1051,9 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale,
 	struct display_buffer dspbuf = { sizeof(str), str, str };
 	struct req_op_context op_context;
 
+	GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, expire_client_start, TRACE_INFO,
+				      clientid, "nfs_client_id_expire start");
+
 	/* Initialize op_context */
 	init_op_context_simple(&op_context, NULL, NULL);
 
@@ -1022,6 +1083,10 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale,
 			/* Take a ref for clientid and add to list */
 			inc_client_id_ref(clientid);
 			clientid->marked_for_delayed_cleanup = true;
+
+			/* Drop the cid_mutex now so it is safe to take the
+			 * expired_client_ids_list_lock mutex.
+			 */
 			PTHREAD_MUTEX_unlock(&clientid->cid_mutex);
 
 			if (isFullDebug(COMPONENT_CLIENTID)) {
@@ -1052,6 +1117,8 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale,
 	if (isDebug(COMPONENT_CLIENTID)) {
 		display_client_id_rec(&dspbuf, clientid);
 		LogDebug(COMPONENT_CLIENTID, "Expiring {%s}", str);
+		GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, expire_client, TRACE_INFO,
+					      clientid, "Expiring client");
 	}
 
 	if ((clientid->cid_confirmed == CONFIRMED_CLIENT_ID) ||
@@ -1307,6 +1374,8 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale,
  * Once the threshold of number of expired clients reaches,
  * this API is invoked to actually start cleaning them up.
  *
+ * NOTE: Must not be called with the cid_mutex held (lock ordering).
+ *
  * @param[in] conflicted_client The conflicted client id to expire.
  *				If passed NULL, judge and clean all expired
  *				ones in the list.
@@ -1322,18 +1391,25 @@ int reap_expired_client_list(nfs_client_id_t *conflicted_client)
 	nfs_client_record_t *client_rec;
 	int count = 0;
 
+	const uint32_t curr_expired_clients =
+		atomic_fetch_uint32_t(&num_of_curr_expired_clients);
+	GSH_AUTO_TRACEPOINT(
+		nfs4, reap_expired_client_list, TRACE_INFO,
+		"expired_client_threshold={}, curr_expired_clients={}",
+		nfs_param.nfsv4_param.expired_client_threshold,
+		curr_expired_clients);
+
 	/* If feature disabled or no expired clients present
 	 * then skip the expired list reaper task
 	 */
 	if (!((nfs_param.nfsv4_param.expired_client_threshold) &&
-	      (atomic_fetch_uint32_t(&num_of_curr_expired_clients)))) {
+	      (curr_expired_clients))) {
 		return count;
 	} else {
 		LogFullDebug(
 			COMPONENT_CLIENTID,
 			"Reaping expired client list with client(%p) Curr_Expired(%u) Threshold(%u)",
-			conflicted_client,
-			atomic_fetch_uint32_t(&num_of_curr_expired_clients),
+			conflicted_client, curr_expired_clients,
 			nfs_param.nfsv4_param.expired_client_threshold);
 	}
 
@@ -1370,6 +1446,9 @@ int reap_expired_client_list(nfs_client_id_t *conflicted_client)
 			PTHREAD_MUTEX_unlock(&expired_client_ids_list_lock);
 			LogFullDebug(COMPONENT_CLIENTID,
 				     "No expired clients ready for cleanup");
+			GSH_AUTO_TRACEPOINT(
+				nfs4, reap_no_expired, TRACE_INFO,
+				"No expired clients ready for cleanup");
 			return count;
 		}
 
@@ -1380,6 +1459,10 @@ int reap_expired_client_list(nfs_client_id_t *conflicted_client)
 			LogFullDebug(COMPONENT_CLIENTID,
 				     "Skipping client(%p), as it's gone valid.",
 				     expired_client);
+			GSH_CLIENT_ID_AUTO_TRACEPOINT(
+				nfs4, reap_skipping, TRACE_INFO, expired_client,
+				"Skipping client {}, as it's gone valid",
+				expired_client->cid_clientid);
 			glist_del(&expired_client->expired_client);
 			expired_client->marked_for_delayed_cleanup = false;
 			/* Drop ref of the expired_client as it's gone valid */
@@ -1392,6 +1475,10 @@ int reap_expired_client_list(nfs_client_id_t *conflicted_client)
 			display_client_id_rec(&dspbuf, expired_client);
 			LogFullDebug(COMPONENT_CLIENTID, "Expired Client is %s",
 				     str);
+			GSH_CLIENT_ID_AUTO_TRACEPOINT(nfs4, reap_expired_client,
+						      TRACE_INFO,
+						      expired_client,
+						      "Expiring client");
 		}
 
 		/* Get the client record */
