@@ -97,7 +97,7 @@ namespace {
       free_state(test_file_state);
       EXPECT_EQ(0, status.major);
 
-      status = fsal_remove(test_root, TEST_FILE);
+      status = fsal_remove(test_root, TEST_FILE, NULL, NULL);
       EXPECT_EQ(status.major, 0);
       test_file->obj_ops->put_ref(test_file);
       test_file = NULL;
@@ -146,6 +146,8 @@ TEST_F(Commit2EmptyLatencyTest, SMALL_UNSTABLE_WRITE)
 
   write_arg->info = NULL;
   write_arg->state = NULL;
+  write_arg->offset = 0;
+  write_arg->io_request = bytes;
   write_arg->iov_count = 1;
   write_arg->iov[0].iov_len = bytes;
   write_arg->iov[0].iov_base = databuffer;
@@ -183,6 +185,8 @@ TEST_F(Commit2EmptyLatencyTest, SMALL_STABLE_WRITE)
 
   write_arg->info = NULL;
   write_arg->state = NULL;
+  write_arg->offset = 0;
+  write_arg->io_request = bytes;
   write_arg->iov_count = 1;
   write_arg->iov[0].iov_len = bytes;
   write_arg->iov[0].iov_base = databuffer;
@@ -220,6 +224,8 @@ TEST_F(Commit2EmptyLatencyTest, LARGE_UNSTABLE_WRITE)
 
   write_arg->info = NULL;
   write_arg->state = NULL;
+  write_arg->offset = 0;
+  write_arg->io_request = bytes;
   write_arg->iov_count = 1;
   write_arg->iov[0].iov_len = bytes;
   write_arg->iov[0].iov_base = databuffer;
@@ -257,6 +263,8 @@ TEST_F(Commit2EmptyLatencyTest, LARGE_STABLE_WRITE)
 
   write_arg->info = NULL;
   write_arg->state = NULL;
+  write_arg->offset = 0;
+  write_arg->io_request = bytes;
   write_arg->iov_count = 1;
   write_arg->iov[0].iov_len = bytes;
   write_arg->iov[0].iov_base = databuffer;
