@@ -388,6 +388,7 @@ static inline fsal_status_t fsal_commit(struct fsal_obj_handle *obj,
 }
 fsal_status_t fsal_verify2(struct fsal_obj_handle *obj,
 			   fsal_verifier_t verifier);
+fsal_status_t fsal_close2(struct fsal_obj_handle *obj);
 
 /**
  * @brief Prepare an fsal_attrlist for fetching attributes.
@@ -655,7 +656,7 @@ fsal_status_t fsal_listxattr_helper(const char *buf, size_t listlen,
 
 struct fd_lru_parameter {
 	/** Base interval in seconds between runs of the LRU cleaner
-	    thread. Defaults to 60, settable with LRU_Run_Interval. */
+	    thread. Defaults to 90, settable with LRU_Run_Interval. */
 	uint32_t lru_run_interval;
 	/**  If Cache_FDs is false then FDs will remained cached till the LRU
 	 *   reaper thread invokes and tries to close the FDs.
@@ -665,6 +666,11 @@ struct fd_lru_parameter {
 	 *   currentopen >= fds_lowat (FD low watermark).
 	 */
 	bool Cache_FDs;
+	/**
+	 * Whether to close files immediately after opening files and
+	 * using them for read/write/commit. Defaults to false,
+	 * settable with Close_Fast. */
+	bool close_fast;
 	/** The percentage of the system-imposed maximum of file
 	    descriptors at which Ganesha will deny requests.
 	    Defaults to 99, settable with FD_Limit_Percent. */
@@ -702,7 +708,9 @@ struct fd_lru_parameter {
 };
 
 extern int32_t fsal_fd_global_counter;
-extern uint32_t fsal_fd_state_counter;
+extern int32_t fsal_fd_state_counter;
+
+extern bool close_fast;
 
 void fsal_init_fds_limit(struct fd_lru_parameter *params);
 fsal_status_t fd_lru_pkginit(struct fd_lru_parameter *params);
