@@ -459,7 +459,22 @@ struct state_t *nfs4_State_Get_Obj(struct fsal_obj_handle *obj,
 int reserve_lease(nfs_client_id_t *clientid);
 bool reserve_lease_or_expire(nfs_client_id_t *clientid, bool update,
 			     state_owner_t **owner);
-void update_lease(nfs_client_id_t *clientid);
+bool update_lease(nfs_client_id_t *clientid);
+
+static inline void update_lease_simple(nfs_client_id_t *clientid)
+{
+	bool unexpire;
+
+	PTHREAD_MUTEX_lock(&clientid->cid_mutex);
+
+	unexpire = update_lease(clientid);
+
+	PTHREAD_MUTEX_unlock(&clientid->cid_mutex);
+
+	if (unexpire)
+		remove_client_from_expired_client_list(clientid);
+}
+
 bool valid_lease(nfs_client_id_t *clientid, bool is_from_reaper);
 /******************************************************************************
  *
@@ -574,6 +589,31 @@ void log_lock(log_components_t component, log_levels_t debug,
 	log_lock(component, debug, reason, obj, owner, lock, (char *)__FILE__, \
 		 __LINE__, (char *)__func__)
 
+#define LOCK_RQST_FMT \
+	"lock: [ptr = {},id = {},type = {},start = {},length = {}]"
+#define LOCK_RQST_VARS(_lock, _handle)                            \
+	(_lock), (uint64_t)(_handle)->fileid, (_lock)->lock_type, \
+		(_lock)->lock_start, (_lock)->lock_length
+
+#define LOCK__REQUEST_AUTO_TRACEPOINT(_lock, _handle, event, log_level, \
+				      format, ...)                      \
+	GSH_AUTO_TRACEPOINT(lock, event, log_level,                     \
+			    LOCK_RQST_FMT " | " format,                 \
+			    LOCK_RQST_VARS(_lock, _handle), ##__VA_ARGS__)
+
+#define LOCK_FMT \
+	"lock: [fileid = {},type = {},start = {},length = {}, blocked={}]"
+#define LOCK_VARS(_lock)                                                   \
+	((uint64_t)_lock->sle_obj->fileid), _lock->sle_lock.lock_type,     \
+		_lock->sle_lock.lock_start, (_lock)->sle_lock.lock_length, \
+		(_lock->sle_block_data ?                                   \
+			 _lock->sle_block_data->sbd_block_type :           \
+			 STATE_BLOCK_NONE)
+
+#define LOCK_AUTO_TRACEPOINT(_lock, event, log_level, format, ...)         \
+	GSH_AUTO_TRACEPOINT(lock, event, log_level, LOCK_FMT " | " format, \
+			    LOCK_VARS((_lock)), ##__VA_ARGS__)
+
 void dump_all_locks(const char *label);
 
 state_status_t state_add_grant_cookie(struct fsal_obj_handle *obj, void *cookie,
@@ -697,14 +737,15 @@ static inline struct fsal_obj_handle *get_state_obj_ref(state_t *state)
 	return obj;
 }
 
-static inline bool state_same_export(state_t *state, struct gsh_export *export)
+static inline bool state_same_export(state_t *state,
+				     struct gsh_export *state_export)
 {
 	bool same = false;
 
 	PTHREAD_MUTEX_lock(&state->state_mutex);
 
 	if (state->state_export != NULL)
-		same = state->state_export == export;
+		same = state->state_export == state_export;
 
 	PTHREAD_MUTEX_unlock(&state->state_mutex);
 
@@ -773,7 +814,7 @@ static inline bool state_same_owner(state_t *state, state_owner_t *owner)
 
 bool get_state_obj_export_owner_refs(state_t *state,
 				     struct fsal_obj_handle **obj,
-				     struct gsh_export **export,
+				     struct gsh_export **state_export,
 				     state_owner_t **owner);
 
 void state_nfs4_state_wipe(struct state_hdl *ostate);
